@@ -1,7 +1,7 @@
 from pygit2 import Diff
 from gitlib import GitClient
 
-TOKEN = "YOUR_OWN_TOKEN"
+TOKEN = "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"
 
 client = GitClient(token=TOKEN)
 repo = client.get_repo(owner="ArtifexSoftware", project="mujs")
